import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, max , format, extent} from 'd3';
import { useData } from './useData.js';
import { AxisBottom } from './axisBottom.js';
import { AxisLeft } from './axisLeft.js'
import { Marks } from './marks.js'

const width = 960;
const height = 500;
const margin = {
  top: 20,
  bottom: 80,
  left: 100,
  right: 40,
};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 40;

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.right - margin.left;

const App = () => {
  const data = useData();
  
  if (!data) {
    return <pre>Loading...</pre>;
  }
  
const xValue = d => d.sepal_length;
const xAxisLabel = 'Sepal Length';
  
const yValue = d => d.sepal_width;
const yAxisLabel = 'Sepal Width';

const siFormat = format('.2s')
const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G','B');

const xScale = scaleLinear()
  .domain(extent(data, xValue))
  .range([0, innerWidth])
	.nice();

const yScale = scaleLinear()
  .domain(extent(data, yValue))
  .range([0, innerHeight]);
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <AxisBottom xScale={xScale} innerHeight={innerHeight} tickFormat = {xAxisTickFormat} tickOffset = {5}/>
        <AxisLeft yScale={yScale}  innerWidth={innerWidth}  tickOffset = {5}/>
        <Marks data = { data } xScale={xScale} yScale={yScale} xValue = {xValue} yValue = {yValue} tooltipFormat ={xAxisTickFormat} circleRadius={7} />
       <text className = "axis-label" x = {innerWidth / 2} textAnchor="middle" y = {innerHeight+xAxisLabelOffset} > {xAxisLabel} </text>
        <text className = "axis-label" textAnchor="middle" transform={`translate(${-yAxisLabelOffset},${innerHeight/2}) rotate(-90) `}> {yAxisLabel} </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
